@@ -14,6 +14,11 @@ class _QueryComment(dbt.adapters.base.query_headers._QueryComment):
         if not self.query_comment:
             return sql
 
+        # alter or vacuum statements don't seem to support properly query comments
+        # let's just exclude them
+        if any(map(sql.lower().__contains__, ["alter", "drop", "optimize", "vacuum"])):
+            return sql
+
         cleaned_query_comment = self.query_comment.strip().replace("\n", " ")
 
         if self.append:
