@@ -1,7 +1,9 @@
 {% materialization table, adapter='athena' -%}
   {%- set identifier = model['alias'] -%}
 
-  {%- set format = config.get('format', default='parquet') -%}
+  {%- set lf_tags = config.get('lf_tags', default=none) -%}
+  {%- set lf_tags_columns = config.get('lf_tags_columns', default=none) -%}
+  {%- set table_type = config.get('table_type', default='hive') | lower -%}
   {%- set old_relation = adapter.get_relation(database=database, schema=schema, identifier=identifier) -%}
   {%- set target_relation = api.Relation.create(identifier=identifier,
                                                 schema=schema,
@@ -10,35 +12,26 @@
 
   {{ run_hooks(pre_hooks) }}
 
+  -- cleanup
   {%- if old_relation is not none -%}
-    {%- if format != 'iceberg' -%}
-      {{ adapter.drop_relation(old_relation) }}
-    {%- endif -%}
+    {{ drop_relation(old_relation) }}
   {%- endif -%}
 
-  {%- if format == 'iceberg' -%}
-    {%- set tmp_relation = make_temp_relation(target_relation) -%}
-	  {%- set build_sql = create_table_iceberg(target_relation, old_relation, tmp_relation, sql) -%}
-  {% else %}
-    {% set build_sql = create_table_as(False, target_relation, sql) -%}
-  {%- endif -%}
+  -- build model
+  {% call statement('main') -%}
+    {{ create_table_as(False, target_relation, sql) }}
+  {%- endcall %}
 
-  {% call statement("main") %}
-    {{ build_sql }}
-  {% endcall %}
-
-  -- drop tmp table in case of iceberg
-  {%- if format == 'iceberg' -%}
-  	{% do adapter.drop_relation(tmp_relation) %}
-  {%- endif -%}
-
-  -- set table properties
-  {%- if format != 'iceberg' -%}
-    {{ set_table_classification(target_relation, 'parquet') }}
-  {%- endif -%}
+  {% if table_type != 'iceberg' %}
+    {{ set_table_classification(target_relation) }}
+  {% endif %}
 
   {{ run_hooks(post_hooks) }}
 
+  {% if lf_tags is not none or lf_tags_columns is not none %}
+    {{ adapter.add_lf_tags(target_relation.schema, identifier, lf_tags, lf_tags_columns) }}
+  {% endif %}
+
   {% do persist_docs(target_relation, model) %}
 
   {{ return({'relations': [target_relation]}) }}
