@@ -1,10 +1,17 @@
 {% macro create_or_replace_view(run_outside_transaction_hooks=True) %}
   {%- set identifier = model['alias'] -%}
+
+  {%- set lf_tags = config.get('lf_tags', default=none) -%}
+  {%- set lf_tags_columns = config.get('lf_tags_columns', default=none) -%}
   {%- set old_relation = adapter.get_relation(database=database, schema=schema, identifier=identifier) -%}
   {%- set exists_as_view = (old_relation is not none and old_relation.is_view) -%}
   {%- set target_relation = api.Relation.create(
-      identifier=identifier, schema=schema, database=database,
-      type='view') -%}
+      identifier=identifier,
+      schema=schema,
+      database=database,
+      type='view',
+    ) -%}
+
   {% if run_outside_transaction_hooks %}
       -- no transactions on BigQuery
       {{ run_hooks(pre_hooks, inside_transaction=False) }}
@@ -23,6 +30,10 @@
     {{ create_view_as(target_relation, sql) }}
   {%- endcall %}
 
+  {% if lf_tags is not none or lf_tags_columns is not none %}
+    {{ adapter.add_lf_tags(target_relation.schema, identifier, lf_tags, lf_tags_columns) }}
+  {% endif %}
+
   {{ run_hooks(post_hooks, inside_transaction=True) }}
 
   {{ adapter.commit() }}
